<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="en">
<context>
    <name>CountdownTooltip</name>
    <message>
        <source>Click the tray icon 
or press the shortcut again to stop recording</source>
        <translation>Click the tray icon 
or press the shortcut again to stop recording</translation>
    </message>
    <message>
        <source>Do not rotate your screen during recording</source>
        <translation>Do not rotate your screen during recording</translation>
    </message>
</context>
<context>
    <name>IconWidget</name>
    <message>
        <source>Screenshot</source>
        <translation>Screenshot</translation>
    </message>
    <message>
        <source>Recording</source>
        <translation>Recording</translation>
    </message>
</context>
<context>
    <name>MainToolWidget</name>
    <message>
        <source>Close (Esc)</source>
        <translation>Close (Esc)</translation>
    </message>
    <message>
        <source>Copy to clipboard (Enter)</source>
        <translation>Copy to clipboard (Enter)</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Screen Capture</source>
        <translation>Screen Capture</translation>
    </message>
    <message>
        <source>Save failed. Please save it in your home directory.</source>
        <translation>Save failed. Please save it in your home directory.</translation>
    </message>
    <message>
        <source>View</source>
        <translation>View</translation>
    </message>
    <message>
        <source>Screenshot finished</source>
        <translation>Screenshot finished</translation>
    </message>
    <message>
        <source>PNG (*.png);;JPEG (*.jpg *.jpeg);;BMP (*.bmp)</source>
        <translation>PNG (*.png);;JPEG (*.jpg *.jpeg);;BMP (*.bmp)</translation>
    </message>
    <message>
        <source>JPEG (*.jpg *.jpeg);;PNG (*.png);;BMP (*.bmp)</source>
        <translation>JPEG (*.jpg *.jpeg);;PNG (*.png);;BMP (*.bmp)</translation>
    </message>
    <message>
        <source>BMP (*.bmp);;JPEG (*.jpg *.jpeg);;PNG (*.png)</source>
        <translation>BMP (*.bmp);;JPEG (*.jpg *.jpeg);;PNG (*.png)</translation>
    </message>
    <message>
        <source>select-area</source>
        <translation>select-area</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Save</translation>
    </message>
    <message>
        <source>Saved to %1</source>
        <translation>Saved to %1</translation>
    </message>
    <message>
        <source>Ignore</source>
        <translation>Ignore</translation>
    </message>
    <message>
        <source>Clipboard</source>
        <translation>Clipboard</translation>
    </message>
    <message>
        <source>Saving the screen recording file, please wait...</source>
        <translation>Saving the screen recording file, please wait...</translation>
    </message>
    <message>
        <source>As the window effect is disabled during the process, the recording has to be stopped</source>
        <translation>As the window effect is disabled during the process, the recording has to be stopped</translation>
    </message>
    <message>
        <source>Screenshot</source>
        <translation>Screenshot</translation>
    </message>
    <message>
        <source>Scrollshot</source>
        <translation>Scrollshot</translation>
    </message>
    <message>
        <source>Pin Screenshots</source>
        <translation>Pin Screenshots</translation>
    </message>
    <message>
        <source>deepin-screen-recorder</source>
        <translation>deepin-screen-recorder</translation>
    </message>
    <message>
        <source>Open Folder</source>
        <translation>Open Folder</translation>
    </message>
    <message>
        <source>Screenshot finished and copy to clipboard</source>
        <translation>Screenshot finished and copy to clipboard</translation>
    </message>
</context>
<context>
    <name>MenuController</name>
    <message>
        <source>Undo</source>
        <translation>Undo</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Save</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>Exit</translation>
    </message>
</context>
<context>
    <name>PinSaveMenuManager</name>
    <message>
        <source>Each inquiry</source>
        <translation>Each inquiry</translation>
    </message>
    <message>
        <source>Specified Location</source>
        <translation>Specified Location</translation>
    </message>
    <message>
        <source>Set a path on save</source>
        <translation>Set a path on save</translation>
    </message>
    <message>
        <source>Change the path on save</source>
        <translation>Change the path on save</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Pin Screenshots</source>
        <translation>Pin Screenshots</translation>
    </message>
</context>
<context>
    <name>QuickPanelWidget</name>
    <message>
        <source>Screenshot</source>
        <translation>Screenshot</translation>
    </message>
    <message>
        <source>Record</source>
        <translation>Record</translation>
    </message>
</context>
<context>
    <name>RecordIconWidget</name>
    <message>
        <source>Screenshot</source>
        <translation>Screenshot</translation>
    </message>
    <message>
        <source>Recording</source>
        <translation>Recording</translation>
    </message>
</context>
<context>
    <name>RecordProcess</name>
    <message>
        <source>View</source>
        <translation>View</translation>
    </message>
    <message>
        <source>Recording finished</source>
        <translation>Recording finished</translation>
    </message>
    <message>
        <source>Saved to %1</source>
        <translation>Saved to %1</translation>
    </message>
    <message>
        <source>Record</source>
        <translation>Record</translation>
    </message>
    <message>
        <source>Open Folder</source>
        <translation>Open Folder</translation>
    </message>
</context>
<context>
    <name>SaveMenuManager</name>
    <message>
        <source>Each inquiry</source>
        <translation>Each inquiry</translation>
    </message>
    <message>
        <source>Specified location</source>
        <translation>Specified location</translation>
    </message>
    <message>
        <source>Select a location when saving</source>
        <translation>Select a location when saving</translation>
    </message>
    <message>
        <source>Update the location when saving</source>
        <translation>Update the location when saving</translation>
    </message>
</context>
<context>
    <name>Screenshot</name>
    <message>
        <source>Screen Capture will start in %1 seconds</source>
        <translation>Screen Capture will start in %1 seconds</translation>
    </message>
</context>
<context>
    <name>ScrollShotTip</name>
    <message>
        <source>Get help.</source>
        <translation>Get help.</translation>
    </message>
    <message>
        <source>Failed to take a continuous screenshot.</source>
        <translation>Failed to take a continuous screenshot.</translation>
    </message>
    <message>
        <source>Reached the bottom of the scroll area</source>
        <translation>Reached the bottom of the scroll area</translation>
    </message>
    <message>
        <source>Reached the maximum length</source>
        <translation>Reached the maximum length</translation>
    </message>
    <message>
        <source>adjust the capture area</source>
        <translation>adjust the capture area</translation>
    </message>
    <message>
        <source>Scroll your mouse wheel or click to take a scrolling screenshot</source>
        <translation>Scroll your mouse wheel or click to take a scrolling screenshot</translation>
    </message>
    <message>
        <source>Slow down the scrolling speed</source>
        <translation>Slow down the scrolling speed</translation>
    </message>
    <message>
        <source>Invalid area, click to </source>
        <translation>Invalid area, click to </translation>
    </message>
</context>
<context>
    <name>ShapesWidget</name>
    <message>
        <source>Input text here</source>
        <translation>Input text here</translation>
    </message>
</context>
<context>
    <name>Shortcut</name>
    <message>
        <source>Start/Screenshot</source>
        <translation>Start/Screenshot</translation>
    </message>
    <message>
        <source>Exit/Save</source>
        <translation>Exit/Save</translation>
    </message>
    <message>
        <source>Size Adjustment</source>
        <translation>Size Adjustment</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Settings</translation>
    </message>
    <message>
        <source>Quick start</source>
        <translation>Quick start</translation>
    </message>
    <message>
        <source>Window screenshot</source>
        <translation>Window screenshot</translation>
    </message>
    <message>
        <source>Delay screenshot</source>
        <translation>Delay screenshot</translation>
    </message>
    <message>
        <source>Full screenshot</source>
        <translation>Full screenshot</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>Exit</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Save</translation>
    </message>
    <message>
        <source>Rectangle</source>
        <translation>Rectangle</translation>
    </message>
    <message>
        <source>Ellipse</source>
        <translation>Ellipse</translation>
    </message>
    <message>
        <source>Line</source>
        <translation>Line</translation>
    </message>
    <message>
        <source>Pencil</source>
        <translation>Pencil</translation>
    </message>
    <message>
        <source>Text</source>
        <translation>Text</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Delete</translation>
    </message>
    <message>
        <source>Undo</source>
        <translation>Undo</translation>
    </message>
    <message>
        <source>Increase height up</source>
        <translation>Increase height up</translation>
    </message>
    <message>
        <source>Increase height down</source>
        <translation>Increase height down</translation>
    </message>
    <message>
        <source>Increase width left</source>
        <translation>Increase width left</translation>
    </message>
    <message>
        <source>Increase width right</source>
        <translation>Increase width right</translation>
    </message>
    <message>
        <source>Decrease height up</source>
        <translation>Decrease height up</translation>
    </message>
    <message>
        <source>Decrease height down</source>
        <translation>Decrease height down</translation>
    </message>
    <message>
        <source>Decrease width left</source>
        <translation>Decrease width left</translation>
    </message>
    <message>
        <source>Decrease width right</source>
        <translation>Decrease width right</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>Help</translation>
    </message>
    <message>
        <source>Display shortcuts</source>
        <translation>Display shortcuts</translation>
    </message>
    <message>
        <source>Sound</source>
        <translation>Sound</translation>
    </message>
    <message>
        <source>Keystroke</source>
        <translation>Keystroke</translation>
    </message>
    <message>
        <source>Webcam</source>
        <translation>Webcam</translation>
    </message>
    <message>
        <source>Start recording</source>
        <translation>Start recording</translation>
    </message>
    <message>
        <source>Options</source>
        <translation>Options</translation>
    </message>
    <message>
        <source>Start/Recording</source>
        <translation>Start/Recording</translation>
    </message>
    <message>
        <source>Mouse</source>
        <translation>Mouse</translation>
    </message>
    <message>
        <source>Tools</source>
        <translation>Tools</translation>
    </message>
    <message>
        <source>Extract text</source>
        <translation>Extract text</translation>
    </message>
    <message>
        <source>Scrollshot</source>
        <translation>Scrollshot</translation>
    </message>
    <message>
        <source>Pin screenshots</source>
        <translation>Pin screenshots</translation>
    </message>
    <message>
        <source>Start OCR</source>
        <translation>Start OCR</translation>
    </message>
    <message>
        <source>Start scrollshot</source>
        <translation>Start scrollshot</translation>
    </message>
    <message>
        <source>Arrow</source>
        <translation>Arrow</translation>
    </message>
</context>
<context>
    <name>ShotStartPlugin</name>
    <message>
        <source>Screenshot</source>
        <translation>Screenshot</translation>
    </message>
</context>
<context>
    <name>ShotStartRecordPlugin</name>
    <message>
        <source>Record</source>
        <translation>Record</translation>
    </message>
</context>
<context>
    <name>ShotToolWidget</name>
    <message>
        <source>Rectangle
Press and hold Shift to draw a square</source>
        <translation>Rectangle
Press and hold Shift to draw a square</translation>
    </message>
    <message>
        <source>Ellipse
Press and hold Shift to draw a circle</source>
        <translation>Ellipse
Press and hold Shift to draw a circle</translation>
    </message>
    <message>
        <source>Brush
Press and hold Shift to draw a straight line</source>
        <translation>Brush
Press and hold Shift to draw a straight line</translation>
    </message>
    <message>
        <source>Adjust blur strength (Scroll to adjust it)</source>
        <translation>Adjust blur strength (Scroll to adjust it)</translation>
    </message>
    <message>
        <source>Adjust brush size (Scroll to adjust it)</source>
        <translation>Adjust brush size (Scroll to adjust it)</translation>
    </message>
    <message>
        <source>Adjust text size (Scroll to adjust it)</source>
        <translation>Adjust text size (Scroll to adjust it)</translation>
    </message>
</context>
<context>
    <name>SubToolWidget</name>
    <message>
        <source>Extract Text</source>
        <translation>Extract Text</translation>
    </message>
    <message>
        <source>Options</source>
        <translation>Options</translation>
    </message>
    <message>
        <source>Save to</source>
        <translation>Save to</translation>
    </message>
    <message>
        <source>Desktop</source>
        <translation>Desktop</translation>
    </message>
    <message>
        <source>Format</source>
        <translation>Format</translation>
    </message>
    <message>
        <source>PNG</source>
        <translation>PNG</translation>
    </message>
    <message>
        <source>JPG</source>
        <translation>JPG</translation>
    </message>
    <message>
        <source>BMP</source>
        <translation>BMP</translation>
    </message>
    <message>
        <source>Change the path on save</source>
        <translation>Change the path on save</translation>
    </message>
    <message>
        <source>Show keystroke (K)</source>
        <translation>Show keystroke (K)</translation>
    </message>
    <message>
        <source>Hide Keystroke (K)</source>
        <translation>Hide Keystroke (K)</translation>
    </message>
    <message>
        <source>Show Keystroke (K)</source>
        <translation>Show Keystroke (K)</translation>
    </message>
    <message>
        <source>Turn on camera (C)</source>
        <translation>Turn on camera (C)</translation>
    </message>
    <message>
        <source>Turn off camera (C)</source>
        <translation>Turn off camera (C)</translation>
    </message>
    <message>
        <source>Screenshot</source>
        <translation>Screenshot</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Settings</translation>
    </message>
    <message>
        <source>Settings (F3)</source>
        <translation>Settings (F3)</translation>
    </message>
    <message>
        <source>Format:</source>
        <translation>Format:</translation>
    </message>
    <message>
        <source>GIF</source>
        <translation>GIF</translation>
    </message>
    <message>
        <source>MP4</source>
        <translation>MP4</translation>
    </message>
    <message>
        <source>MKV</source>
        <translation>MKV</translation>
    </message>
    <message>
        <source>webm</source>
        <translation>webm</translation>
    </message>
    <message>
        <source>FPS:</source>
        <translation>FPS:</translation>
    </message>
    <message>
        <source>5 fps</source>
        <translation>5 fps</translation>
    </message>
    <message>
        <source>10 fps</source>
        <translation>10 fps</translation>
    </message>
    <message>
        <source>20 fps</source>
        <translation>20 fps</translation>
    </message>
    <message>
        <source>24 fps</source>
        <translation>24 fps</translation>
    </message>
    <message>
        <source>30 fps</source>
        <translation>30 fps</translation>
    </message>
    <message>
        <source>Sound</source>
        <translation>Sound</translation>
    </message>
    <message>
        <source>Microphone</source>
        <translation>Microphone</translation>
    </message>
    <message>
        <source>System audio</source>
        <translation>System audio</translation>
    </message>
    <message>
        <source>Show pointer</source>
        <translation>Show pointer</translation>
    </message>
    <message>
        <source>Show click</source>
        <translation>Show click</translation>
    </message>
    <message>
        <source>Videos</source>
        <translation>Videos</translation>
    </message>
    <message>
        <source>Line (L)
Press and hold Shift to draw a vertical or horizontal line</source>
        <translation>Line (L)
Press and hold Shift to draw a vertical or horizontal line</translation>
    </message>
    <message>
        <source>Arrow (X)
Press and hold Shift to draw a vertical or horizontal arrow</source>
        <translation>Arrow (X)
Press and hold Shift to draw a vertical or horizontal arrow</translation>
    </message>
    <message>
        <source>Pencil (P)</source>
        <translation>Pencil (P)</translation>
    </message>
    <message>
        <source>Blur (B)</source>
        <translation>Blur (B)</translation>
    </message>
    <message>
        <source>Text (T)</source>
        <translation>Text (T)</translation>
    </message>
    <message>
        <source>Scrollshot (Alt+I）</source>
        <translation>Scrollshot (Alt+I）</translation>
    </message>
    <message>
        <source>Extract text (Alt+O）</source>
        <translation>Extract text (Alt+O）</translation>
    </message>
    <message>
        <source>Pin screenshots (Alt+P）</source>
        <translation>Pin screenshots (Alt+P）</translation>
    </message>
    <message>
        <source>Undo (Ctrl+Z)</source>
        <translation>Undo (Ctrl+Z)</translation>
    </message>
    <message>
        <source>Record</source>
        <translation>Record</translation>
    </message>
    <message>
        <source>Border Effects</source>
        <translation>Border Effects</translation>
    </message>
    <message>
        <source>None</source>
        <translation>None</translation>
    </message>
    <message>
        <source>Shadow</source>
        <translation>Shadow</translation>
    </message>
    <message>
        <source>Border</source>
        <translation>Border</translation>
    </message>
    <message>
        <source>Device</source>
        <translation>Device</translation>
    </message>
    <message>
        <source>Geometric Tools (R)
Hold down Shift to draw squares or circles.</source>
        <translation>Geometric Tools (R)
Hold down Shift to draw squares or circles.</translation>
    </message>
    <message>
        <source>Save to local</source>
        <translation>Save to local</translation>
    </message>
    <message>
        <source>Save to %1</source>
        <translation>Save to %1</translation>
    </message>
    <message>
        <source>Specified Location</source>
        <translation>Specified Location</translation>
    </message>
    <message>
        <source>Update the location when saving</source>
        <translation>Update the location when saving</translation>
    </message>
    <message>
        <source>Select a location when saving</source>
        <translation>Select a location when saving</translation>
    </message>
</context>
<context>
    <name>ToolBarWidget</name>
    <message>
        <source>Close (Esc)</source>
        <translation>Close (Esc)</translation>
    </message>
    <message>
        <source>Copy to clipboard (Enter)</source>
        <translation>Copy to clipboard (Enter)</translation>
    </message>
    <message>
        <source>OK (Enter)</source>
        <translation>OK (Enter)</translation>
    </message>
</context>
<context>
    <name>TopTips</name>
    <message>
        <source> Adjust the recording area within %1*%2 to get better video effect</source>
        <translation> Adjust the recording area within %1*%2 to get better video effect</translation>
    </message>
</context>
<context>
    <name>Utils</name>
    <message>
        <source>Screen recording is not supported at present</source>
        <translation>Screen recording is not supported at present</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>Exit</translation>
    </message>
</context>
</TS>
